==> sagua_0.1-1.tar.gz: sagua-0.1/include/trace.h <==
#ifndef GUARD_trace_h
#define GUARD_trace_h
// Sagua trace object.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <iostream>
#include <string>

namespace Tracer {

    inline bool& activeTrace()
    {
	static bool activeTrace_;

	return activeTrace_;
    }

#ifdef ENABLE_DEBUGTRACE 

    class Trace {
	public:
	    Trace(const char* name, std::ostream& os = std::cout)
	    : os_(os)
	    {
		if(activeTrace()) {
		    os_ << ">> Enter : " << name << std::endl;
		    functionName_ = std::auto_ptr<std::string>(new std::string(name));
		}
	    }

	    ~Trace()
	    {
		if(activeTrace()) {
		    os_ << "<< Leave : " << *functionName_ << std::endl;
		}
	    }

	    void Debug(const char* msg)
	    {
		if(activeTrace()) {
		    os_ << '[' << *functionName_ << "] " << msg << std::endl;
		}
	    }

	private:
	    std::auto_ptr<std::string> functionName_;
	    std::ostream& os_;
	    
    };
    
#endif

#ifdef DISABLE_DEBUGTRACE

    class Trace {
	public:
	    Trace(const char* name, std::ostream& os = std::cout) {}
	    ~Trace() {}
	    void Debug(const char* msg) {}
    };

#endif    
    
}

#endif

==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/include/trace.h <==
#ifndef GUARD_trace_h
#define GUARD_trace_h
// Sagua trace object.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file trace.h
/// @brief Class for debug trace header file

#include <iostream>
#include <string>

namespace Tracer {

    /// @brief Boolean variable for check activation of tracer.
    ///
    /// To declare in static variable, this forms meyers' singleton. 
    /// @return static boolean variable
    inline bool& activeTrace()
    {
	static bool activeTrace_;

	return activeTrace_;
    }

#ifdef ENABLE_DEBUGTRACE 

    /// @brief Class for debug trace
    class Trace {
	public:
	    /// @brief Constructor for debug trace
	    /// @param name Name to store, function name in most case.
	    /// @param os ostream
	    Trace(const char* name, std::ostream& os = std::cout)
	    : os_(os)
	    {
		if(activeTrace()) {
		    os_ << ">> Enter : " << name << std::endl;
		    functionName_ = std::auto_ptr<std::string>(new std::string(name));
		}
	    }

	    ~Trace()
	    {
		if(activeTrace()) {
		    os_ << "<< Leave : " << *functionName_ << std::endl;
		}
	    }
	    
	    /// @brief Output debug message to ostream
	    /// @param msg Message to output
	    void Debug(const char* msg)
	    {
		if(activeTrace()) {
		    os_ << '[' << *functionName_ << "] " << msg << std::endl;
		}
	    }

	private:
	    Trace(const Trace& trace);
	    Trace& operator=(const Trace& trace);
	
	    std::auto_ptr<std::string> functionName_;	///< string to store
	    std::ostream& os_;				///< ostream
	    
    };
    
#else
    
    /// @brief Class for debug trace
    class Trace {
	public:
	    /// @brief Constructor for debug trace
	    /// @param name Name to store, function name in most case.
	    /// @param os ostream
	    Trace(const char* name, std::ostream& os = std::cout) {}
	    ~Trace() {}
	    /// @brief Output debug message to ostream
	    /// @param msg Message to output
	    void Debug(const char* msg) {}
    };

#endif    
    
}

#endif
